# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.13](https://github.com/k88hudson/plzplz/compare/v0.0.12...v0.0.13) - 2026-03-01

### Fixed

- hooks were being skipped

## [0.0.12](https://github.com/k88hudson/plzplz/compare/v0.0.11...v0.0.12) - 2026-03-01

### Fixed

- safety hatch for hooks
- slightly more helpful non-interactive message from plz hooks

### Other

- Add uv back to the site

## [0.0.11](https://github.com/k88hudson/plzplz/compare/v0.0.10...v0.0.11) - 2026-02-27

### Added

- added a preamble to init templates

### Other

- maybe fix pypi
- remove uv from site until it's fixed
- fix aarch64-unknown-linux-gnu

## [0.0.10](https://github.com/k88hudson/plzplz/compare/v0.0.9...v0.0.10) - 2026-02-26

### Other

- another attempt to fix pypi

## [0.0.9](https://github.com/k88hudson/plzplz/compare/v0.0.8...v0.0.9) - 2026-02-25

### Other

- fix build for pypi
- minor template updates

## [0.0.8](https://github.com/k88hudson/plzplz/compare/v0.0.7...v0.0.8) - 2026-02-25

### Other

- Publish pypi on tags
- update python min version

## [0.0.7](https://github.com/k88hudson/plzplz/compare/v0.0.6...v0.0.7) - 2026-02-25

### Added

- add plz cheatsheet feature to replace example

### Fixed

- added conflict resolution for all the built-in commands

## [0.0.6](https://github.com/k88hudson/plzplz/compare/v0.0.5...v0.0.6) - 2026-02-25

### Added

- plz hooks add
- uvx environment

### Fixed

- plz [task] behavior in a non plz dir

### Other
- installer should install to ~/.local/bin

## [0.0.5](https://github.com/k88hudson/plzplz/compare/v0.0.4...v0.0.5) - 2026-02-24

### Added

- Task groups for templates
- Extends section for global configuration of environment/working dir
- Support for npm
- cargo-dist publishing of binaries

### Fixed

- Hints and cli behavior for missing things
- add release-plz toml

## [0.0.4](https://github.com/k88hudson/plzplz/compare/v0.0.3...v0.0.4) - 2026-02-19

### Added

- Added support for git hooks
- Publishing via pypi
- Some additional hints


### Fixed

- Issue with environments not being added to failure hooks
